EXPORTS
	??1XBoolQuery@ESock@@UAE@XZ @ 1 NONAME ; ESock::XBoolQuery::~XBoolQuery(void)
	??1XConnectionQuerySet@ESock@@UAE@XZ @ 2 NONAME ; ESock::XConnectionQuerySet::~XConnectionQuerySet(void)
	??1XIntQuery@ESock@@UAE@XZ @ 3 NONAME ; ESock::XIntQuery::~XIntQuery(void)
	??1XProviderInfoQuerySet@ESock@@UAE@XZ @ 4 NONAME ; ESock::XProviderInfoQuerySet::~XProviderInfoQuerySet(void)
	??1XText16Query@ESock@@UAE@XZ @ 5 NONAME ; ESock::XText16Query::~XText16Query(void)
	??1XText8Query@ESock@@UAE@XZ @ 6 NONAME ; ESock::XText8Query::~XText8Query(void)
	??1XUintQuery@ESock@@UAE@XZ @ 7 NONAME ; ESock::XUintQuery::~XUintQuery(void)
	?ClearFlags@XConnectionQueryBase@ESock@@AAEXK@Z @ 8 NONAME ; void ESock::XConnectionQueryBase::ClearFlags(unsigned long)
	?DispatchL@XConnectionQuerySet@ESock@@UAE?AW4TProgressAction@XCommsDataObject@2@PAXPAVMPlatsecApiExt@2@@Z @ 9 NONAME ; enum ESock::XCommsDataObject::TProgressAction ESock::XConnectionQuerySet::DispatchL(void *, class ESock::MPlatsecApiExt *)
	?DispatchL@XProviderInfoQuerySet@ESock@@MAE?AW4TProgressAction@XCommsDataObject@2@PAXPAVMPlatsecApiExt@2@@Z @ 10 NONAME ; enum ESock::XCommsDataObject::TProgressAction ESock::XProviderInfoQuerySet::DispatchL(void *, class ESock::MPlatsecApiExt *)
	?FindQuery@XConnectionQuerySet@ESock@@QBEPAVXConnectionQueryBase@2@ABV32@@Z @ 11 NONAME ; class ESock::XConnectionQueryBase * ESock::XConnectionQuerySet::FindQuery(class ESock::XConnectionQueryBase const &) const
	?GetAttribPtr@XBoolQuery@ESock@@EBEPAEH@Z @ 12 NONAME ; unsigned char * ESock::XBoolQuery::GetAttribPtr(int) const
	?GetAttribPtr@XConnectionQueryBase@ESock@@MBEPAEH@Z @ 13 NONAME ; unsigned char * ESock::XConnectionQueryBase::GetAttribPtr(int) const
	?GetAttribPtr@XConnectionQuerySet@ESock@@EBEPAEH@Z @ 14 NONAME ; unsigned char * ESock::XConnectionQuerySet::GetAttribPtr(int) const
	?GetAttribPtr@XIntQuery@ESock@@EBEPAEH@Z @ 15 NONAME ; unsigned char * ESock::XIntQuery::GetAttribPtr(int) const
	?GetAttribPtr@XNullQuery@XConnectionQuerySet@ESock@@EBEPAEH@Z @ 16 NONAME ; unsigned char * ESock::XConnectionQuerySet::XNullQuery::GetAttribPtr(int) const
	?GetAttribPtr@XProviderInfoQuerySet@ESock@@EBEPAEH@Z @ 17 NONAME ; unsigned char * ESock::XProviderInfoQuerySet::GetAttribPtr(int) const
	?GetAttribPtr@XText16Query@ESock@@EBEPAEH@Z @ 18 NONAME ; unsigned char * ESock::XText16Query::GetAttribPtr(int) const
	?GetAttribPtr@XText8Query@ESock@@EBEPAEH@Z @ 19 NONAME ; unsigned char * ESock::XText8Query::GetAttribPtr(int) const
	?GetAttribPtr@XUintQuery@ESock@@EBEPAEH@Z @ 20 NONAME ; unsigned char * ESock::XUintQuery::GetAttribPtr(int) const
	?GetSetting@XBoolQuery@ESock@@MAEXPAVMQueryConnSettingsApiExt@2@PAVMPlatsecApiExt@2@@Z @ 21 NONAME ; void ESock::XBoolQuery::GetSetting(class ESock::MQueryConnSettingsApiExt *, class ESock::MPlatsecApiExt *)
	?GetSetting@XIntQuery@ESock@@MAEXPAVMQueryConnSettingsApiExt@2@PAVMPlatsecApiExt@2@@Z @ 22 NONAME ; void ESock::XIntQuery::GetSetting(class ESock::MQueryConnSettingsApiExt *, class ESock::MPlatsecApiExt *)
	?GetSetting@XNullQuery@XConnectionQuerySet@ESock@@MAEXPAVMQueryConnSettingsApiExt@3@PAVMPlatsecApiExt@3@@Z @ 23 NONAME ; void ESock::XConnectionQuerySet::XNullQuery::GetSetting(class ESock::MQueryConnSettingsApiExt *, class ESock::MPlatsecApiExt *)
	?GetSetting@XText16Query@ESock@@MAEXPAVMQueryConnSettingsApiExt@2@PAVMPlatsecApiExt@2@@Z @ 24 NONAME ; void ESock::XText16Query::GetSetting(class ESock::MQueryConnSettingsApiExt *, class ESock::MPlatsecApiExt *)
	?GetSetting@XText8Query@ESock@@MAEXPAVMQueryConnSettingsApiExt@2@PAVMPlatsecApiExt@2@@Z @ 25 NONAME ; void ESock::XText8Query::GetSetting(class ESock::MQueryConnSettingsApiExt *, class ESock::MPlatsecApiExt *)
	?GetSetting@XUintQuery@ESock@@MAEXPAVMQueryConnSettingsApiExt@2@PAVMPlatsecApiExt@2@@Z @ 26 NONAME ; void ESock::XUintQuery::GetSetting(class ESock::MQueryConnSettingsApiExt *, class ESock::MPlatsecApiExt *)
	?GetVDataTable@XBoolQuery@ESock@@EBEPBUSVDataTableEntry@Meta@@XZ @ 27 NONAME ; struct Meta::SVDataTableEntry const * ESock::XBoolQuery::GetVDataTable(void) const
	?GetVDataTable@XConnectionQueryBase@ESock@@MBEPBUSVDataTableEntry@Meta@@XZ @ 28 NONAME ; struct Meta::SVDataTableEntry const * ESock::XConnectionQueryBase::GetVDataTable(void) const
	?GetVDataTable@XConnectionQuerySet@ESock@@EBEPBUSVDataTableEntry@Meta@@XZ @ 29 NONAME ; struct Meta::SVDataTableEntry const * ESock::XConnectionQuerySet::GetVDataTable(void) const
	?GetVDataTable@XIntQuery@ESock@@EBEPBUSVDataTableEntry@Meta@@XZ @ 30 NONAME ; struct Meta::SVDataTableEntry const * ESock::XIntQuery::GetVDataTable(void) const
	?GetVDataTable@XNullQuery@XConnectionQuerySet@ESock@@EBEPBUSVDataTableEntry@Meta@@XZ @ 31 NONAME ; struct Meta::SVDataTableEntry const * ESock::XConnectionQuerySet::XNullQuery::GetVDataTable(void) const
	?GetVDataTable@XProviderInfoQuerySet@ESock@@EBEPBUSVDataTableEntry@Meta@@XZ @ 32 NONAME ; struct Meta::SVDataTableEntry const * ESock::XProviderInfoQuerySet::GetVDataTable(void) const
	?GetVDataTable@XText16Query@ESock@@EBEPBUSVDataTableEntry@Meta@@XZ @ 33 NONAME ; struct Meta::SVDataTableEntry const * ESock::XText16Query::GetVDataTable(void) const
	?GetVDataTable@XText8Query@ESock@@EBEPBUSVDataTableEntry@Meta@@XZ @ 34 NONAME ; struct Meta::SVDataTableEntry const * ESock::XText8Query::GetVDataTable(void) const
	?GetVDataTable@XUintQuery@ESock@@EBEPBUSVDataTableEntry@Meta@@XZ @ 35 NONAME ; struct Meta::SVDataTableEntry const * ESock::XUintQuery::GetVDataTable(void) const
	?GetVDataTableStatic@XBoolQuery@ESock@@CAPBUSVDataTableEntry@Meta@@XZ @ 36 NONAME ; struct Meta::SVDataTableEntry const * ESock::XBoolQuery::GetVDataTableStatic(void)
	?GetVDataTableStatic@XConnectionQueryBase@ESock@@KAPBUSVDataTableEntry@Meta@@XZ @ 37 NONAME ; struct Meta::SVDataTableEntry const * ESock::XConnectionQueryBase::GetVDataTableStatic(void)
	?GetVDataTableStatic@XConnectionQuerySet@ESock@@CAPBUSVDataTableEntry@Meta@@XZ @ 38 NONAME ; struct Meta::SVDataTableEntry const * ESock::XConnectionQuerySet::GetVDataTableStatic(void)
	?GetVDataTableStatic@XIntQuery@ESock@@CAPBUSVDataTableEntry@Meta@@XZ @ 39 NONAME ; struct Meta::SVDataTableEntry const * ESock::XIntQuery::GetVDataTableStatic(void)
	?GetVDataTableStatic@XNullQuery@XConnectionQuerySet@ESock@@CAPBUSVDataTableEntry@Meta@@XZ @ 40 NONAME ; struct Meta::SVDataTableEntry const * ESock::XConnectionQuerySet::XNullQuery::GetVDataTableStatic(void)
	?GetVDataTableStatic@XProviderInfoQuerySet@ESock@@CAPBUSVDataTableEntry@Meta@@XZ @ 41 NONAME ; struct Meta::SVDataTableEntry const * ESock::XProviderInfoQuerySet::GetVDataTableStatic(void)
	?GetVDataTableStatic@XText16Query@ESock@@CAPBUSVDataTableEntry@Meta@@XZ @ 42 NONAME ; struct Meta::SVDataTableEntry const * ESock::XText16Query::GetVDataTableStatic(void)
	?GetVDataTableStatic@XText8Query@ESock@@CAPBUSVDataTableEntry@Meta@@XZ @ 43 NONAME ; struct Meta::SVDataTableEntry const * ESock::XText8Query::GetVDataTableStatic(void)
	?GetVDataTableStatic@XUintQuery@ESock@@CAPBUSVDataTableEntry@Meta@@XZ @ 44 NONAME ; struct Meta::SVDataTableEntry const * ESock::XUintQuery::GetVDataTableStatic(void)
	?LoadL@XConnectionQueryBase@ESock@@SAPAV12@AAVTPtrC8@@@Z @ 45 NONAME ; class ESock::XConnectionQueryBase * ESock::XConnectionQueryBase::LoadL(class TPtrC8 &)
	?SetError@XConnectionQueryBase@ESock@@IAEXH@Z @ 46 NONAME ; void ESock::XConnectionQueryBase::SetError(int)
	?SetFlags@XConnectionQueryBase@ESock@@AAEXK@Z @ 47 NONAME ; void ESock::XConnectionQueryBase::SetFlags(unsigned long)
	?SetQueryAnswered@XConnectionQueryBase@ESock@@IAEXXZ @ 48 NONAME ; void ESock::XConnectionQueryBase::SetQueryAnswered(void)
	?DispatchL@XTunnelConnQuerySet@ESock@@UAE?AW4TProgressAction@XCommsDataObject@2@PAXPAVMPlatsecApiExt@2@@Z @ 49 NONAME ; enum ESock::XCommsDataObject::TProgressAction ESock::XTunnelConnQuerySet::DispatchL(void *, class ESock::MPlatsecApiExt *)
	?GetAttribPtr@XTunnelConnQuerySet@ESock@@EBEPAEH@Z @ 50 NONAME ; unsigned char * ESock::XTunnelConnQuerySet::GetAttribPtr(int) const
	?GetVDataTable@XTunnelConnQuerySet@ESock@@EBEPBUSVDataTableEntry@Meta@@XZ @ 51 NONAME ; struct Meta::SVDataTableEntry const * ESock::XTunnelConnQuerySet::GetVDataTable(void) const
	?GetVDataTableStatic@XTunnelConnQuerySet@ESock@@CAPBUSVDataTableEntry@Meta@@XZ @ 52 NONAME ; struct Meta::SVDataTableEntry const * ESock::XTunnelConnQuerySet::GetVDataTableStatic(void)

